# Monarch Digital Backups

This module allows you to configure backups using the Backup and Migrate
module and stored in the Monarch Digital AWS S3 account.

## Dependencies

* Backup and Migrate (https://www.drupal.org/project/backup_migrate)
* Backup and Migrate: AWS S3 (https://www.drupal.org/project/backup_migrate_aws_s3)
* Key (https://www.drupal.org/project/key)
* Key AWS (https://www.drupal.org/project/key_aws)

## Configuration

By default this module configures a system of rolling database backups on the following schedule:

1. Daily backups (keep last 7)
2. Weekly backups (keep last 8)
3. Monthly backups (keep last 6)
4. Yearly backups (keep indefinitly)

> *Note*: By default this module only configures database backups. Additional backup schedules may need to be added for the public/private filesystem.

## Module Set Up

### Step 1: Create a new AWS user and S3 bucket

**Create an API user**

1. Log into https://aws.amazon.com/ as the root Monarch user
2. Select IAM from the Service menu
3. Select Users under Access management and click "Add users"
4. Name the new user according to the site name
5. Select "Access key - Programmatic access" for AWS credential type
6. Under set permissions, select "Attache existing policies directly"
7. In the list of policies, select "MonarchBackups" and click "Next"
8. You do not need to add tags. Click "Next"
9. Review the configuration and click "Create user"
10. Copy the Access key ID and Secret access key and save them in Zoho Vault

**Create a new S3 bucket under monarch_backups**

1. Select S3 from the Service menu
2. Select the "monarch_backups" bucket
3. Click "Create folder"
4. Name the folder with the same name as the IAM user created in the previous section.

### Step 2: Add AWS keys to drupal

**Create an AWS configuration file**

1. Create a configuration file with the AWS access and secret keys according to this description: https://docs.aws.amazon.com/cli/latest/userguide/cli-configure-files.html
2. Store the file outside of the webroot. For example: in `.aws/credentials`
3. Make sure the credentials file is ignored in .gitignore

**Configure keys in Drupal**

1. Log into Drupal as an administrator
2. Go to `/admin/config/system/keys` ("Configuration" => "System" => "Keys" in the admin menu) and click "Add Key"
3. Enter an appropriate key name and description
4. For Key type, select "AWS S3"
5. For Key provider, settings, select "AWS Credentials"
6. For File location, enter the absolute or relative path the aws credentials file created above
7. Save the configuration

### Step 3: Add the key to the backup and migration destination

1. Log into Drupal as an administrator
2. Go to `/admin/config/development/backup_migrate/settings` ("Configuration" => "Development" => "Backup and Migrate" => "Settings" from the admin menu) and click "Destinations"
3. Edit the "Monarch AWS S3" destination
4. For S3 Credentials Key, select the key you created above
5. For S3 Region, select 'us-east-1'
6. Click save and then re-edit the destination (this will populate the S3 Bucket dropdown from AWS)
7. Select "monarch_backups" for S3 Bucket
8. Enter the subfolder name created above
9. Click save

### Step 4: Enable backup schedules

1. Log into Drupal as an administrator
2. Go to `/admin/config/development/backup_migrate/schedule` ("Configuration" => "Development" => "Backup and Migrate" => "Schedule" from the admin menu)
3. Edit the schedule(s) you would like to enable
